<?php
// Function to add a new settings page

use JetBrains\PhpStorm\Language;

function ftc_custom_gpt_settings_page()
{
    add_submenu_page(
        'ftc_admin_menu',
        'Setting GPT',
        'Setting GPT',
        'manage_options',
        'ftc-gpt-settings',
        'ftc_custom_settings_page_content',
        99
    );
}
add_action('admin_menu', 'ftc_custom_gpt_settings_page', 99);

// Function to display the settings page content
function ftc_custom_settings_page_content()
{
?>
    <div class="wrap">
        <h2>THEME FTC Open AI Settings</h2>
        <form method="post" action="options.php">
            <?php
            settings_fields('ftc_custom_gpt_settings');
            echo '<div class="ftc-openai-setting">';
            do_settings_sections('ftc-gpt-settings');
            echo '</div>';
            ?>
            <input type="submit" name="submit" class="button button-primary" value="Save Changes" style="float: right; margin-right: 0px; margin-top: 10px">
        </form>
    </div>
<?php
}

// Function to register and add fields to the settings page
function ftc_custom_gpt_settings_init()
{
    register_setting(
        'ftc_custom_gpt_settings',
        'ftc_gpt_content',
        array('sanitize_callback' => 'sanitize_text_field')
    );

    register_setting(
        'ftc_custom_gpt_settings',
        'temperature',
        array('sanitize_callback' => 'sanitize_text_field')
    );

    add_settings_section(
        'my_custom_section',
        'OpenAI Settings',
        'my_custom_section_callback',
        'ftc-gpt-settings'
    );

    add_settings_field(
        'ftc_gpt_content',
        'Open AI Setting',
        'ftc_gpt_content_callback',
        'ftc-gpt-settings',
        'my_custom_section'
    );
    add_settings_field(
        'temperature',
        'Temperature',
        'ftc_gpt_tem_callback',
        'ftc-gpt-settings',
        'my_custom_section'
    );
}
add_action('admin_init', 'ftc_custom_gpt_settings_init');

// Callback function for the section
function my_custom_section_callback()
{
    echo '<p>Enter your settings below:</p>';
}

function ftc_gpt_tem_callback()
{
    $val = get_option('temperature');
    if (!$val) {
        $val = 0.8;
    }
    echo ' <div class="value-temperature">
    <label><strong>Temperature: </strong></label>
    <input type="range" id="temperature" step="0.1" name="temperature" min="0" value="' . $val . '" max="2">
    <span class="number">' . $val . '</span>
    </div>
    <p style="width: 650px; font-size: 13px; max-width: 100%;">What sampling temperature to use, between 0 and 2. Higher values like 0.8 will make the output more random, while lower values like 0.2 will make it more focused and deterministic.</p>';
}

// Callback function for the content field
function ftc_gpt_content_callback()
{
    $content = get_option('ftc_gpt_content');
    $svg = '<svg xmlns="http://www.w3.org/2000/svg" class="svg-eye" width="15px" height="15px" viewBox="0 0 24 24" fill="none">
    <path fill-rule="evenodd" clip-rule="evenodd" d="M6.30147 15.5771C4.77832 14.2684 3.6904 12.7726 3.18002 12C3.6904 11.2274 4.77832 9.73158 6.30147 8.42294C7.87402 7.07185 9.81574 6 12 6C14.1843 6 16.1261 7.07185 17.6986 8.42294C19.2218 9.73158 20.3097 11.2274 20.8201 12C20.3097 12.7726 19.2218 14.2684 17.6986 15.5771C16.1261 16.9282 14.1843 18 12 18C9.81574 18 7.87402 16.9282 6.30147 15.5771ZM12 4C9.14754 4 6.75717 5.39462 4.99812 6.90595C3.23268 8.42276 2.00757 10.1376 1.46387 10.9698C1.05306 11.5985 1.05306 12.4015 1.46387 13.0302C2.00757 13.8624 3.23268 15.5772 4.99812 17.0941C6.75717 18.6054 9.14754 20 12 20C14.8525 20 17.2429 18.6054 19.002 17.0941C20.7674 15.5772 21.9925 13.8624 22.5362 13.0302C22.947 12.4015 22.947 11.5985 22.5362 10.9698C21.9925 10.1376 20.7674 8.42276 19.002 6.90595C17.2429 5.39462 14.8525 4 12 4ZM10 12C10 10.8954 10.8955 10 12 10C13.1046 10 14 10.8954 14 12C14 13.1046 13.1046 14 12 14C10.8955 14 10 13.1046 10 12ZM12 8C9.7909 8 8.00004 9.79086 8.00004 12C8.00004 14.2091 9.7909 16 12 16C14.2092 16 16 14.2091 16 12C16 9.79086 14.2092 8 12 8Z" fill="#000000"/>
    </svg>';
    echo '
        <label for="openai-api-key" class="block mb-[13px]"><strong>OpenAi API Key</strong><a class="" style="margin-left: 10px" href="https://platform.openai.com/account/api-keys" target="_blank">I don"t have a key <svg aria-hidden="true" focusable="false" data-prefix="fas" data-icon="arrow-up-right-from-square" class="svg-inline--fa fa-arrow-up-right-from-square " role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512">
        <path fill="currentColor" d="M320 0c-17.7 0-32 14.3-32 32s14.3 32 32 32h82.7L201.4 265.4c-12.5 12.5-12.5 32.8 0 45.3s32.8 12.5 45.3 0L448 109.3V192c0 17.7 14.3 32 32 32s32-14.3 32-32V32c0-17.7-14.3-32-32-32H320zM80 32C35.8 32 0 67.8 0 112V432c0 44.2 35.8 80 80 80H400c44.2 0 80-35.8 80-80V320c0-17.7-14.3-32-32-32s-32 14.3-32 32V432c0 8.8-7.2 16-16 16H80c-8.8 0-16-7.2-16-16V112c0-8.8 7.2-16 16-16H192c17.7 0 32-14.3 32-32s-14.3-32-32-32H80z"></path>
        </svg></a></label>
        <div class="flex relative content-key-ai">
        <input type="password" required="" placeholder="Enter a openai api key" class="" name="ftc_gpt_content" id="openai-api-key" min="0" autocomplete="off" value="' . esc_attr($content) . '" style="border: 1px solid #eee; box-shadow: none;">';
        echo $svg;
    echo '<style>
    svg:not(:root).svg-inline--fa, svg:not(:host).svg-inline--fa {
        overflow: visible;
        box-sizing: content-box;
    }
    .svg-inline--fa {
        display: var(--fa-display, inline-block);
        height: 1em;
        overflow: visible;
        vertical-align: -0.125em;
    }
    .ftc-openai-setting {
        background: #fff;
        padding: 25px 30px;
        border-radius: 5px;
    }
    .content-key-ai {
        margin: 20px 0;
    }
    .content-key-ai input{
        width: 350px;
        max-width: 100%;
        padding-right: 30px;
    }
    .value-temperature {
        display: flex;
        align-items: center;
        margin-top: 30px;
        gap: 38px;
        max-width: 320px;
        position:relative
    }
    .value-temperature span.number {
        position: absolute;
        right: -30px;
        top: -2px;
    }
    .ftc-openai-setting tbody tr {
        border-bottom: 1px solid #ebebeb;
    }
    .content-key-ai svg.svg-eye {
        right: 25px;
        position: relative;
        cursor: pointer;
    }
    .content-key-ai svg.svg-eye:hover path {
        fill: #0075ff;
    }
    span.eye-close:before {
        content: "";
        position: absolute;
        width: 20px;
        height: 1px;
        background: #333;
        display: block;
        z-index: 99999;
        top: 7px;
        right: 22px;
        transform: rotate(-45deg);
    }
    </style>';
}

//includes css, js
add_action('admin_enqueue_scripts', 'ftc_gpt_admin_scripts');
add_action('wp_enqueue_scripts', 'ftc_gpt_admin_scripts', 9999);
add_action('wp_enqueue_scripts', 'ftc_css_gpt', 1000);

function ftc_gpt_admin_scripts(){
    wp_enqueue_script('ftc-gpt-script', get_template_directory_uri() . '/inc/gpt/script.js', array('jquery'), null, true);
}

function ftc_css_gpt(){
    wp_enqueue_style('ftc-gpt-css', get_template_directory_uri() . '/inc/gpt/styles.css');
}

// ajax get openai key
add_action('wp_ajax_ftc_get_open_ai_key', 'ftc_get_open_ai_key');
add_action('wp_ajax_nopriv_ftc_get_open_ai_key', 'ftc_get_open_ai_key');

function ftc_get_open_ai_key()
{
    $api_key = get_option('ftc_gpt_content');
    $temperature = get_option('temperature');
    $current_language = get_locale();
    if ($api_key) {
        $arr = array(
            "code" => 200,
            "key"  => $api_key,
            "temperature" => $temperature,
            "message" => 'Success',
            'language' => $current_language
        );
        wp_send_json($arr);
    } else {
        $arr = array(
            "code" => 404,
            "message" => 'Not found key'
        );
        wp_send_json($arr);
    }
    wp_die();
}


//ajax auto generate
add_action('wp_ajax_ftc_call_api_gpt', 'ftc_call_api_gpt');
add_action('wp_ajax_nopriv_ftc_call_api_gpt', 'ftc_call_api_gpt');

function ftc_call_api_gpt()
{
    global $smof_data;
    if(!$smof_data['ftc_review_summary'] || !$smof_data['ftc_review_summary_auto']){
       echo '';
       wp_die();
       return;
    }
    $api_url = 'https://api.openai.com/v1/completions';
    $openai_api_key = get_option('ftc_gpt_content'); //'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';
    $temperature = floatval(get_option('temperature'));
    if(!$temperature){
        $temperature = 0.8;
    }
    $language = get_locale();
    $title = $_POST['product_title'];
    $headers = array(
        'Content-Type' => 'application/json',
        'Authorization' => 'Bearer ' . $openai_api_key,
    );

    $data = array(
        'model' => 'gpt-3.5-turbo-instruct',
        'prompt' => 'Analyze summary overview, the pros and cons of "' . $title.'", answer by '.$language,
        'temperature' => $temperature,
        'max_tokens' => 500,
        'top_p' => 1,
        'frequency_penalty' => 0,
        'presence_penalty' => 0,
    );

    $args = array(
        'timeout'     => 3000,
        'body' => json_encode($data),
        'headers' => $headers,
    );

    $response = wp_remote_post($api_url, $args);

    if (is_wp_error($response)) {
        // Handle error
        echo '';
        // echo 'Error: ' . $response->get_error_message();
    } else {
        // Handle success
        $body = wp_remote_retrieve_body($response);
        echo $body;
    }
    wp_die();
}


function custom_admin_styles()
{
    echo '<style>
    .mo-si-toast-message{
      width: 320px;
      position:fixed;
      padding: 12px 16px;
      border-radius:8px;
      right: 15px;
      top: 15px;
      z-index: 9999999;
      box-shadow: 0px 4px 8px 0px #0014330A;
      display: flex;
      align-items: center;
      transition: 1s;
    }
    .mo-si-toast-message.tl{
      left: 15px;
      top: 15px;
      right: auto;
    }
    .mo-si-toast-message.bl{
      bottom: 15px;
      top: auto;
      left: 15px;
      right: auto;
    }
    .mo-si-toast-message.br{
      bottom: 15px;
      top: auto;
      left: auto;
      right: 15px;
    }
    .mo-si-toast-message.error{
      background: #FDEAEC;
      color: #EE2D41;
    }
    .mo-si-toast-message.warning{
      background: #FEEEE6;
      color: #F05800;
    }
    .mo-si-toast-message.success{
      background: #E6FAF0;
      color: #00D16D;
    }
    input#input-call-gpt {
        width: 320px;
        height: 32px;
        font-size: 14px;
        margin-right: 10px;
        padding: 0px 10px;
        line-height: 32px;
    }
    .form-gen-gpt-content{
        margin: 15px 0;
        background: #eeee;
        padding: 10px;
        border-radius: 4px;
        text-align: right;
    }
    .icon-loading-gpt {
        position: absolute !important;
        bottom: 0;
        left: 0;
        z-index: 999999;
        width: 100% !important;
        height: calc(100% + 40px) !important;
        background: rgb(220 215 215 / 54%) !important;
    }
    .icon-loading-gpt svg {
        width: 70px;
        top: 50%;
        position: absolute;
        left: 50%;
        transform: translate(-50%, -50%);
    }
    .edit-post-header__center {
        display: flex;
        flex-grow: 1;
        justify-content: left;
        align-items: center;
    }
    button.custom-gen-post {
        height: 33px;
        display: flex !important;
        align-items: center;
        gap: 10px;
    }
    .custom-gen-post svg {
        width: 18px;
        height: 18px;
    }
    </style>';
}
add_action('admin_head', 'custom_admin_styles');
